@@ -11,7 +11,7 @@ use Text::Unidecode;
 use Carp;
 
 use vars qw($VERSION);
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 use 5.008000;
 
@@ -38,6 +38,7 @@ sub encode
 	if (scalar(@_) == 1) {
 		my $string = shift;
 		$string = unidecode($string) if ($obj->{'unidecode'});
+		return undef unless defined $string && $string !~ /^\s*$/;
 		return $obj->_do_encode($string);
 	# Expand list
 	} elsif (scalar(@_) > 1) {
@@ -60,6 +61,9 @@ sub compare
 	my $string1 = shift;
 	my $string2 = shift;
 
+    return 0 unless defined $string1 && $string1 !~ /^\s*$/;
+    return 0 unless defined $string2 && $string2 !~ /^\s*$/;
+
 	# Extremely rare case ;-)	
 	return 100 if ($string1 eq $string2);
 
@@ -71,6 +75,11 @@ sub compare
 		return 99 if ($string1 eq $string2);
 	}
 	
+	my $value1 = $obj->_do_encode($string1);
+	my $value2 = $obj->_do_encode($string2);
+	
+	return 0 unless (defined $value1 && defined $value2);
+	
 	return $obj->_do_compare($obj->_do_encode($string1),$obj->_do_encode($string2));
 }
 	
@@ -126,6 +135,7 @@ sub _is_inlist
 # ----------------------------------------------------------------
 {
 	my $string = shift;
+	return 0 unless defined $string;
 	my $list = (scalar @_ == 1 && ref($_[0]) eq 'ARRAY') ? shift : \@_;
 	 
 	return 1 if grep {$string eq $_ } @$list;
@@ -205,6 +215,8 @@ Additional attributes may be defined by the various implementation classes.
 Encodes the given string or list of strings. Returns a single value, array or
 array reference depending on the caller context and parameters.
 
+Returns undef on an empty/undefined/whitespace only string.
+
 =head2 compare
 
  $RETURN_CODE = $obj->compare($STRING1,$STRING2);
@@ -212,8 +224,8 @@ array reference depending on the caller context and parameters.
 The return code is an integer between 100 and 0 indicating the likelihood that
 the to results are the same. 100  means that the strings are completely
 identical. 99 means that the strings match after all non-latin characters
-have been transliterated. Values in between 98 and 1 usually mean that the given 
-strings match. 0 means that the used alogorithm couldn't match the two 
+have been transliterated. Values in between 98 and 1 usually mean that the 
+given strings match. 0 means that the used alogorithm couldn't match the two 
 strings at all.
 C<compare> is a shortcut to the C<$obj-&gt;_do_compare($CODE1,$CODE2)> method. 
 
